# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SyncGhDestinationArgs', 'SyncGhDestination']

@pulumi.input_type
class SyncGhDestinationArgs:
    def __init__(__self__, *,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 app_name: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
                 environment_name: Optional[pulumi.Input[_builtins.str]] = None,
                 granularity: Optional[pulumi.Input[_builtins.str]] = None,
                 installation_id: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_name: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_owner: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 secrets_location: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SyncGhDestination resource.
        :param pulumi.Input[_builtins.str] access_token: Fine-grained or personal access token.
               Can be omitted and directly provided to Vault using the `GITHUB_ACCESS_TOKEN` environment
               variable.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv4_addresses: Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
               for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv6_addresses: Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
               for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] allowed_ports: Set of allowed ports for outbound connections from Vault to the
               destination. If not set, all ports are allowed. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] app_name: The user-defined name of the GitHub App configuration. This is a reference to the name used   
               on the new endpoint when configuring the GitHub app on the Vault Server. Can be modified.
               Takes precedence over the `access_token` field.
        :param pulumi.Input[_builtins.bool] disable_strict_networking: If set to `true`, disables strict networking enforcement
               for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
               Defaults to `false`. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] environment_name: Environment name for the destination. Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] granularity: Determines what level of information is synced as a distinct resource
               at the destination. Supports `secret-path` and `secret-key`.
        :param pulumi.Input[_builtins.int] installation_id: The ID of the installation generated by GitHub when the app referenced by the `app_name` 
               was installed in the user's GitHub account. Can be modified. Necessary if the `app_name` field is also provided.
        :param pulumi.Input[_builtins.str] name: Unique name of the GitHub destination.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        :param pulumi.Input[_builtins.str] repository_name: Name of the repository.
               Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_NAME` environment
               variable.
        :param pulumi.Input[_builtins.str] repository_owner: GitHub organization or username that owns the repository.
               Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_OWNER` environment
               variable.
        :param pulumi.Input[_builtins.str] secret_name_template: Template describing how to generate external secret names.
               Supports a subset of the Go Template syntax.
        :param pulumi.Input[_builtins.str] secrets_location: Location where secrets are stored in the destination. Requires Vault 1.18+.
        """
        if access_token is not None:
            pulumi.set(__self__, "access_token", access_token)
        if allowed_ipv4_addresses is not None:
            pulumi.set(__self__, "allowed_ipv4_addresses", allowed_ipv4_addresses)
        if allowed_ipv6_addresses is not None:
            pulumi.set(__self__, "allowed_ipv6_addresses", allowed_ipv6_addresses)
        if allowed_ports is not None:
            pulumi.set(__self__, "allowed_ports", allowed_ports)
        if app_name is not None:
            pulumi.set(__self__, "app_name", app_name)
        if disable_strict_networking is not None:
            pulumi.set(__self__, "disable_strict_networking", disable_strict_networking)
        if environment_name is not None:
            pulumi.set(__self__, "environment_name", environment_name)
        if granularity is not None:
            pulumi.set(__self__, "granularity", granularity)
        if installation_id is not None:
            pulumi.set(__self__, "installation_id", installation_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if repository_name is not None:
            pulumi.set(__self__, "repository_name", repository_name)
        if repository_owner is not None:
            pulumi.set(__self__, "repository_owner", repository_owner)
        if secret_name_template is not None:
            pulumi.set(__self__, "secret_name_template", secret_name_template)
        if secrets_location is not None:
            pulumi.set(__self__, "secrets_location", secrets_location)

    @_builtins.property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Fine-grained or personal access token.
        Can be omitted and directly provided to Vault using the `GITHUB_ACCESS_TOKEN` environment
        variable.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_token", value)

    @_builtins.property
    @pulumi.getter(name="allowedIpv4Addresses")
    def allowed_ipv4_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
        for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv4_addresses")

    @allowed_ipv4_addresses.setter
    def allowed_ipv4_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_ipv4_addresses", value)

    @_builtins.property
    @pulumi.getter(name="allowedIpv6Addresses")
    def allowed_ipv6_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
        for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv6_addresses")

    @allowed_ipv6_addresses.setter
    def allowed_ipv6_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_ipv6_addresses", value)

    @_builtins.property
    @pulumi.getter(name="allowedPorts")
    def allowed_ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        Set of allowed ports for outbound connections from Vault to the
        destination. If not set, all ports are allowed. Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ports")

    @allowed_ports.setter
    def allowed_ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "allowed_ports", value)

    @_builtins.property
    @pulumi.getter(name="appName")
    def app_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The user-defined name of the GitHub App configuration. This is a reference to the name used   
        on the new endpoint when configuring the GitHub app on the Vault Server. Can be modified.
        Takes precedence over the `access_token` field.
        """
        return pulumi.get(self, "app_name")

    @app_name.setter
    def app_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_name", value)

    @_builtins.property
    @pulumi.getter(name="disableStrictNetworking")
    def disable_strict_networking(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to `true`, disables strict networking enforcement
        for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
        Defaults to `false`. Requires Vault 1.19+.
        """
        return pulumi.get(self, "disable_strict_networking")

    @disable_strict_networking.setter
    def disable_strict_networking(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_strict_networking", value)

    @_builtins.property
    @pulumi.getter(name="environmentName")
    def environment_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Environment name for the destination. Requires Vault 1.18+.
        """
        return pulumi.get(self, "environment_name")

    @environment_name.setter
    def environment_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "environment_name", value)

    @_builtins.property
    @pulumi.getter
    def granularity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines what level of information is synced as a distinct resource
        at the destination. Supports `secret-path` and `secret-key`.
        """
        return pulumi.get(self, "granularity")

    @granularity.setter
    def granularity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "granularity", value)

    @_builtins.property
    @pulumi.getter(name="installationId")
    def installation_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the installation generated by GitHub when the app referenced by the `app_name` 
        was installed in the user's GitHub account. Can be modified. Necessary if the `app_name` field is also provided.
        """
        return pulumi.get(self, "installation_id")

    @installation_id.setter
    def installation_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "installation_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique name of the GitHub destination.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="repositoryName")
    def repository_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the repository.
        Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_NAME` environment
        variable.
        """
        return pulumi.get(self, "repository_name")

    @repository_name.setter
    def repository_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_name", value)

    @_builtins.property
    @pulumi.getter(name="repositoryOwner")
    def repository_owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        GitHub organization or username that owns the repository.
        Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_OWNER` environment
        variable.
        """
        return pulumi.get(self, "repository_owner")

    @repository_owner.setter
    def repository_owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_owner", value)

    @_builtins.property
    @pulumi.getter(name="secretNameTemplate")
    def secret_name_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Template describing how to generate external secret names.
        Supports a subset of the Go Template syntax.
        """
        return pulumi.get(self, "secret_name_template")

    @secret_name_template.setter
    def secret_name_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_name_template", value)

    @_builtins.property
    @pulumi.getter(name="secretsLocation")
    def secrets_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Location where secrets are stored in the destination. Requires Vault 1.18+.
        """
        return pulumi.get(self, "secrets_location")

    @secrets_location.setter
    def secrets_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secrets_location", value)


@pulumi.input_type
class _SyncGhDestinationState:
    def __init__(__self__, *,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 app_name: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
                 environment_name: Optional[pulumi.Input[_builtins.str]] = None,
                 granularity: Optional[pulumi.Input[_builtins.str]] = None,
                 installation_id: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_name: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_owner: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 secrets_location: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SyncGhDestination resources.
        :param pulumi.Input[_builtins.str] access_token: Fine-grained or personal access token.
               Can be omitted and directly provided to Vault using the `GITHUB_ACCESS_TOKEN` environment
               variable.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv4_addresses: Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
               for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv6_addresses: Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
               for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] allowed_ports: Set of allowed ports for outbound connections from Vault to the
               destination. If not set, all ports are allowed. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] app_name: The user-defined name of the GitHub App configuration. This is a reference to the name used   
               on the new endpoint when configuring the GitHub app on the Vault Server. Can be modified.
               Takes precedence over the `access_token` field.
        :param pulumi.Input[_builtins.bool] disable_strict_networking: If set to `true`, disables strict networking enforcement
               for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
               Defaults to `false`. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] environment_name: Environment name for the destination. Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] granularity: Determines what level of information is synced as a distinct resource
               at the destination. Supports `secret-path` and `secret-key`.
        :param pulumi.Input[_builtins.int] installation_id: The ID of the installation generated by GitHub when the app referenced by the `app_name` 
               was installed in the user's GitHub account. Can be modified. Necessary if the `app_name` field is also provided.
        :param pulumi.Input[_builtins.str] name: Unique name of the GitHub destination.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        :param pulumi.Input[_builtins.str] repository_name: Name of the repository.
               Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_NAME` environment
               variable.
        :param pulumi.Input[_builtins.str] repository_owner: GitHub organization or username that owns the repository.
               Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_OWNER` environment
               variable.
        :param pulumi.Input[_builtins.str] secret_name_template: Template describing how to generate external secret names.
               Supports a subset of the Go Template syntax.
        :param pulumi.Input[_builtins.str] secrets_location: Location where secrets are stored in the destination. Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] type: The type of the secrets destination (`gh`).
        """
        if access_token is not None:
            pulumi.set(__self__, "access_token", access_token)
        if allowed_ipv4_addresses is not None:
            pulumi.set(__self__, "allowed_ipv4_addresses", allowed_ipv4_addresses)
        if allowed_ipv6_addresses is not None:
            pulumi.set(__self__, "allowed_ipv6_addresses", allowed_ipv6_addresses)
        if allowed_ports is not None:
            pulumi.set(__self__, "allowed_ports", allowed_ports)
        if app_name is not None:
            pulumi.set(__self__, "app_name", app_name)
        if disable_strict_networking is not None:
            pulumi.set(__self__, "disable_strict_networking", disable_strict_networking)
        if environment_name is not None:
            pulumi.set(__self__, "environment_name", environment_name)
        if granularity is not None:
            pulumi.set(__self__, "granularity", granularity)
        if installation_id is not None:
            pulumi.set(__self__, "installation_id", installation_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if repository_name is not None:
            pulumi.set(__self__, "repository_name", repository_name)
        if repository_owner is not None:
            pulumi.set(__self__, "repository_owner", repository_owner)
        if secret_name_template is not None:
            pulumi.set(__self__, "secret_name_template", secret_name_template)
        if secrets_location is not None:
            pulumi.set(__self__, "secrets_location", secrets_location)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Fine-grained or personal access token.
        Can be omitted and directly provided to Vault using the `GITHUB_ACCESS_TOKEN` environment
        variable.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_token", value)

    @_builtins.property
    @pulumi.getter(name="allowedIpv4Addresses")
    def allowed_ipv4_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
        for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv4_addresses")

    @allowed_ipv4_addresses.setter
    def allowed_ipv4_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_ipv4_addresses", value)

    @_builtins.property
    @pulumi.getter(name="allowedIpv6Addresses")
    def allowed_ipv6_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
        for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv6_addresses")

    @allowed_ipv6_addresses.setter
    def allowed_ipv6_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_ipv6_addresses", value)

    @_builtins.property
    @pulumi.getter(name="allowedPorts")
    def allowed_ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        Set of allowed ports for outbound connections from Vault to the
        destination. If not set, all ports are allowed. Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ports")

    @allowed_ports.setter
    def allowed_ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "allowed_ports", value)

    @_builtins.property
    @pulumi.getter(name="appName")
    def app_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The user-defined name of the GitHub App configuration. This is a reference to the name used   
        on the new endpoint when configuring the GitHub app on the Vault Server. Can be modified.
        Takes precedence over the `access_token` field.
        """
        return pulumi.get(self, "app_name")

    @app_name.setter
    def app_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_name", value)

    @_builtins.property
    @pulumi.getter(name="disableStrictNetworking")
    def disable_strict_networking(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to `true`, disables strict networking enforcement
        for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
        Defaults to `false`. Requires Vault 1.19+.
        """
        return pulumi.get(self, "disable_strict_networking")

    @disable_strict_networking.setter
    def disable_strict_networking(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_strict_networking", value)

    @_builtins.property
    @pulumi.getter(name="environmentName")
    def environment_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Environment name for the destination. Requires Vault 1.18+.
        """
        return pulumi.get(self, "environment_name")

    @environment_name.setter
    def environment_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "environment_name", value)

    @_builtins.property
    @pulumi.getter
    def granularity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines what level of information is synced as a distinct resource
        at the destination. Supports `secret-path` and `secret-key`.
        """
        return pulumi.get(self, "granularity")

    @granularity.setter
    def granularity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "granularity", value)

    @_builtins.property
    @pulumi.getter(name="installationId")
    def installation_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the installation generated by GitHub when the app referenced by the `app_name` 
        was installed in the user's GitHub account. Can be modified. Necessary if the `app_name` field is also provided.
        """
        return pulumi.get(self, "installation_id")

    @installation_id.setter
    def installation_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "installation_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique name of the GitHub destination.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="repositoryName")
    def repository_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the repository.
        Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_NAME` environment
        variable.
        """
        return pulumi.get(self, "repository_name")

    @repository_name.setter
    def repository_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_name", value)

    @_builtins.property
    @pulumi.getter(name="repositoryOwner")
    def repository_owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        GitHub organization or username that owns the repository.
        Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_OWNER` environment
        variable.
        """
        return pulumi.get(self, "repository_owner")

    @repository_owner.setter
    def repository_owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_owner", value)

    @_builtins.property
    @pulumi.getter(name="secretNameTemplate")
    def secret_name_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Template describing how to generate external secret names.
        Supports a subset of the Go Template syntax.
        """
        return pulumi.get(self, "secret_name_template")

    @secret_name_template.setter
    def secret_name_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_name_template", value)

    @_builtins.property
    @pulumi.getter(name="secretsLocation")
    def secrets_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Location where secrets are stored in the destination. Requires Vault 1.18+.
        """
        return pulumi.get(self, "secrets_location")

    @secrets_location.setter
    def secrets_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secrets_location", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the secrets destination (`gh`).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("vault:secrets/syncGhDestination:SyncGhDestination")
class SyncGhDestination(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 app_name: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
                 environment_name: Optional[pulumi.Input[_builtins.str]] = None,
                 granularity: Optional[pulumi.Input[_builtins.str]] = None,
                 installation_id: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_name: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_owner: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 secrets_location: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        gh = vault.secrets.SyncGhDestination("gh",
            name="gh-dest",
            access_token=access_token,
            repository_owner=repo_owner,
            repository_name="repo-name-example",
            secret_name_template="vault_{{ .MountAccessor | lowercase }}_{{ .SecretPath | lowercase }}",
            secrets_location="repository",
            environment_name="production",
            allowed_ipv4_addresses=[
                "192.168.1.0/24",
                "10.0.0.0/8",
            ],
            allowed_ipv6_addresses=["2001:db8::/32"],
            allowed_ports=[
                443,
                80,
                22,
            ],
            disable_strict_networking=False)
        ```

        ## Import

        GitHub Secrets sync destinations can be imported using the `name`, e.g.

        ```sh
        $ pulumi import vault:secrets/syncGhDestination:SyncGhDestination gh gh-dest
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_token: Fine-grained or personal access token.
               Can be omitted and directly provided to Vault using the `GITHUB_ACCESS_TOKEN` environment
               variable.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv4_addresses: Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
               for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv6_addresses: Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
               for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] allowed_ports: Set of allowed ports for outbound connections from Vault to the
               destination. If not set, all ports are allowed. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] app_name: The user-defined name of the GitHub App configuration. This is a reference to the name used   
               on the new endpoint when configuring the GitHub app on the Vault Server. Can be modified.
               Takes precedence over the `access_token` field.
        :param pulumi.Input[_builtins.bool] disable_strict_networking: If set to `true`, disables strict networking enforcement
               for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
               Defaults to `false`. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] environment_name: Environment name for the destination. Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] granularity: Determines what level of information is synced as a distinct resource
               at the destination. Supports `secret-path` and `secret-key`.
        :param pulumi.Input[_builtins.int] installation_id: The ID of the installation generated by GitHub when the app referenced by the `app_name` 
               was installed in the user's GitHub account. Can be modified. Necessary if the `app_name` field is also provided.
        :param pulumi.Input[_builtins.str] name: Unique name of the GitHub destination.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        :param pulumi.Input[_builtins.str] repository_name: Name of the repository.
               Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_NAME` environment
               variable.
        :param pulumi.Input[_builtins.str] repository_owner: GitHub organization or username that owns the repository.
               Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_OWNER` environment
               variable.
        :param pulumi.Input[_builtins.str] secret_name_template: Template describing how to generate external secret names.
               Supports a subset of the Go Template syntax.
        :param pulumi.Input[_builtins.str] secrets_location: Location where secrets are stored in the destination. Requires Vault 1.18+.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SyncGhDestinationArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        gh = vault.secrets.SyncGhDestination("gh",
            name="gh-dest",
            access_token=access_token,
            repository_owner=repo_owner,
            repository_name="repo-name-example",
            secret_name_template="vault_{{ .MountAccessor | lowercase }}_{{ .SecretPath | lowercase }}",
            secrets_location="repository",
            environment_name="production",
            allowed_ipv4_addresses=[
                "192.168.1.0/24",
                "10.0.0.0/8",
            ],
            allowed_ipv6_addresses=["2001:db8::/32"],
            allowed_ports=[
                443,
                80,
                22,
            ],
            disable_strict_networking=False)
        ```

        ## Import

        GitHub Secrets sync destinations can be imported using the `name`, e.g.

        ```sh
        $ pulumi import vault:secrets/syncGhDestination:SyncGhDestination gh gh-dest
        ```

        :param str resource_name: The name of the resource.
        :param SyncGhDestinationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SyncGhDestinationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 app_name: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
                 environment_name: Optional[pulumi.Input[_builtins.str]] = None,
                 granularity: Optional[pulumi.Input[_builtins.str]] = None,
                 installation_id: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_name: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_owner: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 secrets_location: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SyncGhDestinationArgs.__new__(SyncGhDestinationArgs)

            __props__.__dict__["access_token"] = None if access_token is None else pulumi.Output.secret(access_token)
            __props__.__dict__["allowed_ipv4_addresses"] = allowed_ipv4_addresses
            __props__.__dict__["allowed_ipv6_addresses"] = allowed_ipv6_addresses
            __props__.__dict__["allowed_ports"] = allowed_ports
            __props__.__dict__["app_name"] = app_name
            __props__.__dict__["disable_strict_networking"] = disable_strict_networking
            __props__.__dict__["environment_name"] = environment_name
            __props__.__dict__["granularity"] = granularity
            __props__.__dict__["installation_id"] = installation_id
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["repository_name"] = repository_name
            __props__.__dict__["repository_owner"] = repository_owner
            __props__.__dict__["secret_name_template"] = secret_name_template
            __props__.__dict__["secrets_location"] = secrets_location
            __props__.__dict__["type"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["accessToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SyncGhDestination, __self__).__init__(
            'vault:secrets/syncGhDestination:SyncGhDestination',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_token: Optional[pulumi.Input[_builtins.str]] = None,
            allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
            app_name: Optional[pulumi.Input[_builtins.str]] = None,
            disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
            environment_name: Optional[pulumi.Input[_builtins.str]] = None,
            granularity: Optional[pulumi.Input[_builtins.str]] = None,
            installation_id: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            namespace: Optional[pulumi.Input[_builtins.str]] = None,
            repository_name: Optional[pulumi.Input[_builtins.str]] = None,
            repository_owner: Optional[pulumi.Input[_builtins.str]] = None,
            secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
            secrets_location: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'SyncGhDestination':
        """
        Get an existing SyncGhDestination resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_token: Fine-grained or personal access token.
               Can be omitted and directly provided to Vault using the `GITHUB_ACCESS_TOKEN` environment
               variable.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv4_addresses: Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
               for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv6_addresses: Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
               for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] allowed_ports: Set of allowed ports for outbound connections from Vault to the
               destination. If not set, all ports are allowed. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] app_name: The user-defined name of the GitHub App configuration. This is a reference to the name used   
               on the new endpoint when configuring the GitHub app on the Vault Server. Can be modified.
               Takes precedence over the `access_token` field.
        :param pulumi.Input[_builtins.bool] disable_strict_networking: If set to `true`, disables strict networking enforcement
               for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
               Defaults to `false`. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] environment_name: Environment name for the destination. Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] granularity: Determines what level of information is synced as a distinct resource
               at the destination. Supports `secret-path` and `secret-key`.
        :param pulumi.Input[_builtins.int] installation_id: The ID of the installation generated by GitHub when the app referenced by the `app_name` 
               was installed in the user's GitHub account. Can be modified. Necessary if the `app_name` field is also provided.
        :param pulumi.Input[_builtins.str] name: Unique name of the GitHub destination.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        :param pulumi.Input[_builtins.str] repository_name: Name of the repository.
               Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_NAME` environment
               variable.
        :param pulumi.Input[_builtins.str] repository_owner: GitHub organization or username that owns the repository.
               Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_OWNER` environment
               variable.
        :param pulumi.Input[_builtins.str] secret_name_template: Template describing how to generate external secret names.
               Supports a subset of the Go Template syntax.
        :param pulumi.Input[_builtins.str] secrets_location: Location where secrets are stored in the destination. Requires Vault 1.18+.
        :param pulumi.Input[_builtins.str] type: The type of the secrets destination (`gh`).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SyncGhDestinationState.__new__(_SyncGhDestinationState)

        __props__.__dict__["access_token"] = access_token
        __props__.__dict__["allowed_ipv4_addresses"] = allowed_ipv4_addresses
        __props__.__dict__["allowed_ipv6_addresses"] = allowed_ipv6_addresses
        __props__.__dict__["allowed_ports"] = allowed_ports
        __props__.__dict__["app_name"] = app_name
        __props__.__dict__["disable_strict_networking"] = disable_strict_networking
        __props__.__dict__["environment_name"] = environment_name
        __props__.__dict__["granularity"] = granularity
        __props__.__dict__["installation_id"] = installation_id
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["repository_name"] = repository_name
        __props__.__dict__["repository_owner"] = repository_owner
        __props__.__dict__["secret_name_template"] = secret_name_template
        __props__.__dict__["secrets_location"] = secrets_location
        __props__.__dict__["type"] = type
        return SyncGhDestination(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Fine-grained or personal access token.
        Can be omitted and directly provided to Vault using the `GITHUB_ACCESS_TOKEN` environment
        variable.
        """
        return pulumi.get(self, "access_token")

    @_builtins.property
    @pulumi.getter(name="allowedIpv4Addresses")
    def allowed_ipv4_addresses(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
        for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv4_addresses")

    @_builtins.property
    @pulumi.getter(name="allowedIpv6Addresses")
    def allowed_ipv6_addresses(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
        for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv6_addresses")

    @_builtins.property
    @pulumi.getter(name="allowedPorts")
    def allowed_ports(self) -> pulumi.Output[Optional[Sequence[_builtins.int]]]:
        """
        Set of allowed ports for outbound connections from Vault to the
        destination. If not set, all ports are allowed. Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ports")

    @_builtins.property
    @pulumi.getter(name="appName")
    def app_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The user-defined name of the GitHub App configuration. This is a reference to the name used   
        on the new endpoint when configuring the GitHub app on the Vault Server. Can be modified.
        Takes precedence over the `access_token` field.
        """
        return pulumi.get(self, "app_name")

    @_builtins.property
    @pulumi.getter(name="disableStrictNetworking")
    def disable_strict_networking(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If set to `true`, disables strict networking enforcement
        for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
        Defaults to `false`. Requires Vault 1.19+.
        """
        return pulumi.get(self, "disable_strict_networking")

    @_builtins.property
    @pulumi.getter(name="environmentName")
    def environment_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Environment name for the destination. Requires Vault 1.18+.
        """
        return pulumi.get(self, "environment_name")

    @_builtins.property
    @pulumi.getter
    def granularity(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Determines what level of information is synced as a distinct resource
        at the destination. Supports `secret-path` and `secret-key`.
        """
        return pulumi.get(self, "granularity")

    @_builtins.property
    @pulumi.getter(name="installationId")
    def installation_id(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The ID of the installation generated by GitHub when the app referenced by the `app_name` 
        was installed in the user's GitHub account. Can be modified. Necessary if the `app_name` field is also provided.
        """
        return pulumi.get(self, "installation_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Unique name of the GitHub destination.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="repositoryName")
    def repository_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the repository.
        Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_NAME` environment
        variable.
        """
        return pulumi.get(self, "repository_name")

    @_builtins.property
    @pulumi.getter(name="repositoryOwner")
    def repository_owner(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        GitHub organization or username that owns the repository.
        Can be omitted and directly provided to Vault using the `GITHUB_REPOSITORY_OWNER` environment
        variable.
        """
        return pulumi.get(self, "repository_owner")

    @_builtins.property
    @pulumi.getter(name="secretNameTemplate")
    def secret_name_template(self) -> pulumi.Output[_builtins.str]:
        """
        Template describing how to generate external secret names.
        Supports a subset of the Go Template syntax.
        """
        return pulumi.get(self, "secret_name_template")

    @_builtins.property
    @pulumi.getter(name="secretsLocation")
    def secrets_location(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Location where secrets are stored in the destination. Requires Vault 1.18+.
        """
        return pulumi.get(self, "secrets_location")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the secrets destination (`gh`).
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SecretScopeArgs', 'SecretScope']

@pulumi.input_type
class SecretScopeArgs:
    def __init__(__self__, *,
                 path: pulumi.Input[_builtins.str],
                 scope: pulumi.Input[_builtins.str],
                 force: Optional[pulumi.Input[_builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SecretScope resource.
        :param pulumi.Input[_builtins.str] path: The unique path this backend should be mounted at. Must
               not begin or end with a `/`. Defaults to `kmip`.
        :param pulumi.Input[_builtins.str] scope: Name of the scope.
        :param pulumi.Input[_builtins.bool] force: Boolean field to force deletion even if there are managed objects in the scope.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        """
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "scope", scope)
        if force is not None:
            pulumi.set(__self__, "force", force)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Input[_builtins.str]:
        """
        The unique path this backend should be mounted at. Must
        not begin or end with a `/`. Defaults to `kmip`.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter
    def scope(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the scope.
        """
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "scope", value)

    @_builtins.property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean field to force deletion even if there are managed objects in the scope.
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)


@pulumi.input_type
class _SecretScopeState:
    def __init__(__self__, *,
                 force: Optional[pulumi.Input[_builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 scope: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SecretScope resources.
        :param pulumi.Input[_builtins.bool] force: Boolean field to force deletion even if there are managed objects in the scope.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] path: The unique path this backend should be mounted at. Must
               not begin or end with a `/`. Defaults to `kmip`.
        :param pulumi.Input[_builtins.str] scope: Name of the scope.
        """
        if force is not None:
            pulumi.set(__self__, "force", force)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)

    @_builtins.property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean field to force deletion even if there are managed objects in the scope.
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique path this backend should be mounted at. Must
        not begin or end with a `/`. Defaults to `kmip`.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter
    def scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the scope.
        """
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "scope", value)


@pulumi.type_token("vault:kmip/secretScope:SecretScope")
class SecretScope(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 force: Optional[pulumi.Input[_builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 scope: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages KMIP Secret Scopes in a Vault server. This feature requires
        Vault Enterprise. See the [Vault documentation](https://www.vaultproject.io/docs/secrets/kmip)
        for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        default = vault.kmip.SecretBackend("default",
            path="kmip",
            description="Vault KMIP backend")
        dev = vault.kmip.SecretScope("dev",
            path=default.path,
            scope="dev",
            force=True)
        ```

        ## Import

        KMIP Secret scope can be imported using the `path`, e.g.

        ```sh
        $ pulumi import vault:kmip/secretScope:SecretScope dev kmip
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] force: Boolean field to force deletion even if there are managed objects in the scope.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] path: The unique path this backend should be mounted at. Must
               not begin or end with a `/`. Defaults to `kmip`.
        :param pulumi.Input[_builtins.str] scope: Name of the scope.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecretScopeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages KMIP Secret Scopes in a Vault server. This feature requires
        Vault Enterprise. See the [Vault documentation](https://www.vaultproject.io/docs/secrets/kmip)
        for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        default = vault.kmip.SecretBackend("default",
            path="kmip",
            description="Vault KMIP backend")
        dev = vault.kmip.SecretScope("dev",
            path=default.path,
            scope="dev",
            force=True)
        ```

        ## Import

        KMIP Secret scope can be imported using the `path`, e.g.

        ```sh
        $ pulumi import vault:kmip/secretScope:SecretScope dev kmip
        ```

        :param str resource_name: The name of the resource.
        :param SecretScopeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretScopeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 force: Optional[pulumi.Input[_builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 scope: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretScopeArgs.__new__(SecretScopeArgs)

            __props__.__dict__["force"] = force
            __props__.__dict__["namespace"] = namespace
            if path is None and not opts.urn:
                raise TypeError("Missing required property 'path'")
            __props__.__dict__["path"] = path
            if scope is None and not opts.urn:
                raise TypeError("Missing required property 'scope'")
            __props__.__dict__["scope"] = scope
        super(SecretScope, __self__).__init__(
            'vault:kmip/secretScope:SecretScope',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            force: Optional[pulumi.Input[_builtins.bool]] = None,
            namespace: Optional[pulumi.Input[_builtins.str]] = None,
            path: Optional[pulumi.Input[_builtins.str]] = None,
            scope: Optional[pulumi.Input[_builtins.str]] = None) -> 'SecretScope':
        """
        Get an existing SecretScope resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] force: Boolean field to force deletion even if there are managed objects in the scope.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[_builtins.str] path: The unique path this backend should be mounted at. Must
               not begin or end with a `/`. Defaults to `kmip`.
        :param pulumi.Input[_builtins.str] scope: Name of the scope.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretScopeState.__new__(_SecretScopeState)

        __props__.__dict__["force"] = force
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["path"] = path
        __props__.__dict__["scope"] = scope
        return SecretScope(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def force(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Boolean field to force deletion even if there are managed objects in the scope.
        """
        return pulumi.get(self, "force")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Output[_builtins.str]:
        """
        The unique path this backend should be mounted at. Must
        not begin or end with a `/`. Defaults to `kmip`.
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter
    def scope(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the scope.
        """
        return pulumi.get(self, "scope")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SyncVercelDestinationArgs', 'SyncVercelDestination']

@pulumi.input_type
class SyncVercelDestinationArgs:
    def __init__(__self__, *,
                 access_token: pulumi.Input[_builtins.str],
                 deployment_environments: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 project_id: pulumi.Input[_builtins.str],
                 allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
                 granularity: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SyncVercelDestination resource.
        :param pulumi.Input[_builtins.str] access_token: Vercel API access token with the permissions to manage environment
               variables.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] deployment_environments: Deployment environments where the environment variables
               are available. Accepts `development`, `preview` and `production`.
        :param pulumi.Input[_builtins.str] project_id: Project ID where to manage environment variables.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv4_addresses: Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
               for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv6_addresses: Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
               for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] allowed_ports: Set of allowed ports for outbound connections from Vault to the
               destination. If not set, all ports are allowed. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.bool] disable_strict_networking: If set to `true`, disables strict networking enforcement
               for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
               Defaults to `false`. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] granularity: Determines what level of information is synced as a distinct resource
               at the destination. Supports `secret-path` and `secret-key`.
        :param pulumi.Input[_builtins.str] name: Unique name of the GitHub destination.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        :param pulumi.Input[_builtins.str] secret_name_template: Template describing how to generate external secret names.
               Supports a subset of the Go Template syntax.
        :param pulumi.Input[_builtins.str] team_id: Team ID where to manage environment variables.
        """
        pulumi.set(__self__, "access_token", access_token)
        pulumi.set(__self__, "deployment_environments", deployment_environments)
        pulumi.set(__self__, "project_id", project_id)
        if allowed_ipv4_addresses is not None:
            pulumi.set(__self__, "allowed_ipv4_addresses", allowed_ipv4_addresses)
        if allowed_ipv6_addresses is not None:
            pulumi.set(__self__, "allowed_ipv6_addresses", allowed_ipv6_addresses)
        if allowed_ports is not None:
            pulumi.set(__self__, "allowed_ports", allowed_ports)
        if disable_strict_networking is not None:
            pulumi.set(__self__, "disable_strict_networking", disable_strict_networking)
        if granularity is not None:
            pulumi.set(__self__, "granularity", granularity)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if secret_name_template is not None:
            pulumi.set(__self__, "secret_name_template", secret_name_template)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> pulumi.Input[_builtins.str]:
        """
        Vercel API access token with the permissions to manage environment
        variables.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "access_token", value)

    @_builtins.property
    @pulumi.getter(name="deploymentEnvironments")
    def deployment_environments(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        Deployment environments where the environment variables
        are available. Accepts `development`, `preview` and `production`.
        """
        return pulumi.get(self, "deployment_environments")

    @deployment_environments.setter
    def deployment_environments(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "deployment_environments", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Project ID where to manage environment variables.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="allowedIpv4Addresses")
    def allowed_ipv4_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
        for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv4_addresses")

    @allowed_ipv4_addresses.setter
    def allowed_ipv4_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_ipv4_addresses", value)

    @_builtins.property
    @pulumi.getter(name="allowedIpv6Addresses")
    def allowed_ipv6_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
        for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv6_addresses")

    @allowed_ipv6_addresses.setter
    def allowed_ipv6_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_ipv6_addresses", value)

    @_builtins.property
    @pulumi.getter(name="allowedPorts")
    def allowed_ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        Set of allowed ports for outbound connections from Vault to the
        destination. If not set, all ports are allowed. Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ports")

    @allowed_ports.setter
    def allowed_ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "allowed_ports", value)

    @_builtins.property
    @pulumi.getter(name="disableStrictNetworking")
    def disable_strict_networking(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to `true`, disables strict networking enforcement
        for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
        Defaults to `false`. Requires Vault 1.19+.
        """
        return pulumi.get(self, "disable_strict_networking")

    @disable_strict_networking.setter
    def disable_strict_networking(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_strict_networking", value)

    @_builtins.property
    @pulumi.getter
    def granularity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines what level of information is synced as a distinct resource
        at the destination. Supports `secret-path` and `secret-key`.
        """
        return pulumi.get(self, "granularity")

    @granularity.setter
    def granularity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "granularity", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique name of the GitHub destination.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="secretNameTemplate")
    def secret_name_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Template describing how to generate external secret names.
        Supports a subset of the Go Template syntax.
        """
        return pulumi.get(self, "secret_name_template")

    @secret_name_template.setter
    def secret_name_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_name_template", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Team ID where to manage environment variables.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.input_type
class _SyncVercelDestinationState:
    def __init__(__self__, *,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 deployment_environments: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
                 granularity: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SyncVercelDestination resources.
        :param pulumi.Input[_builtins.str] access_token: Vercel API access token with the permissions to manage environment
               variables.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv4_addresses: Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
               for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv6_addresses: Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
               for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] allowed_ports: Set of allowed ports for outbound connections from Vault to the
               destination. If not set, all ports are allowed. Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] deployment_environments: Deployment environments where the environment variables
               are available. Accepts `development`, `preview` and `production`.
        :param pulumi.Input[_builtins.bool] disable_strict_networking: If set to `true`, disables strict networking enforcement
               for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
               Defaults to `false`. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] granularity: Determines what level of information is synced as a distinct resource
               at the destination. Supports `secret-path` and `secret-key`.
        :param pulumi.Input[_builtins.str] name: Unique name of the GitHub destination.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        :param pulumi.Input[_builtins.str] project_id: Project ID where to manage environment variables.
        :param pulumi.Input[_builtins.str] secret_name_template: Template describing how to generate external secret names.
               Supports a subset of the Go Template syntax.
        :param pulumi.Input[_builtins.str] team_id: Team ID where to manage environment variables.
        :param pulumi.Input[_builtins.str] type: The type of the secrets destination (`vercel-project`).
        """
        if access_token is not None:
            pulumi.set(__self__, "access_token", access_token)
        if allowed_ipv4_addresses is not None:
            pulumi.set(__self__, "allowed_ipv4_addresses", allowed_ipv4_addresses)
        if allowed_ipv6_addresses is not None:
            pulumi.set(__self__, "allowed_ipv6_addresses", allowed_ipv6_addresses)
        if allowed_ports is not None:
            pulumi.set(__self__, "allowed_ports", allowed_ports)
        if deployment_environments is not None:
            pulumi.set(__self__, "deployment_environments", deployment_environments)
        if disable_strict_networking is not None:
            pulumi.set(__self__, "disable_strict_networking", disable_strict_networking)
        if granularity is not None:
            pulumi.set(__self__, "granularity", granularity)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if secret_name_template is not None:
            pulumi.set(__self__, "secret_name_template", secret_name_template)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Vercel API access token with the permissions to manage environment
        variables.
        """
        return pulumi.get(self, "access_token")

    @access_token.setter
    def access_token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_token", value)

    @_builtins.property
    @pulumi.getter(name="allowedIpv4Addresses")
    def allowed_ipv4_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
        for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv4_addresses")

    @allowed_ipv4_addresses.setter
    def allowed_ipv4_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_ipv4_addresses", value)

    @_builtins.property
    @pulumi.getter(name="allowedIpv6Addresses")
    def allowed_ipv6_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
        for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv6_addresses")

    @allowed_ipv6_addresses.setter
    def allowed_ipv6_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "allowed_ipv6_addresses", value)

    @_builtins.property
    @pulumi.getter(name="allowedPorts")
    def allowed_ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]:
        """
        Set of allowed ports for outbound connections from Vault to the
        destination. If not set, all ports are allowed. Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ports")

    @allowed_ports.setter
    def allowed_ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]]):
        pulumi.set(self, "allowed_ports", value)

    @_builtins.property
    @pulumi.getter(name="deploymentEnvironments")
    def deployment_environments(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Deployment environments where the environment variables
        are available. Accepts `development`, `preview` and `production`.
        """
        return pulumi.get(self, "deployment_environments")

    @deployment_environments.setter
    def deployment_environments(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "deployment_environments", value)

    @_builtins.property
    @pulumi.getter(name="disableStrictNetworking")
    def disable_strict_networking(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to `true`, disables strict networking enforcement
        for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
        Defaults to `false`. Requires Vault 1.19+.
        """
        return pulumi.get(self, "disable_strict_networking")

    @disable_strict_networking.setter
    def disable_strict_networking(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_strict_networking", value)

    @_builtins.property
    @pulumi.getter
    def granularity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines what level of information is synced as a distinct resource
        at the destination. Supports `secret-path` and `secret-key`.
        """
        return pulumi.get(self, "granularity")

    @granularity.setter
    def granularity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "granularity", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique name of the GitHub destination.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project ID where to manage environment variables.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="secretNameTemplate")
    def secret_name_template(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Template describing how to generate external secret names.
        Supports a subset of the Go Template syntax.
        """
        return pulumi.get(self, "secret_name_template")

    @secret_name_template.setter
    def secret_name_template(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_name_template", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Team ID where to manage environment variables.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the secrets destination (`vercel-project`).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("vault:secrets/syncVercelDestination:SyncVercelDestination")
class SyncVercelDestination(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 deployment_environments: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
                 granularity: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        vercel = vault.secrets.SyncVercelDestination("vercel",
            name="vercel-dest",
            access_token=access_token,
            project_id=project_id,
            deployment_environments=[
                "development",
                "preview",
                "production",
            ],
            secret_name_template="vault_{{ .MountAccessor | lowercase }}_{{ .SecretPath | lowercase }}",
            allowed_ipv4_addresses=[
                "192.168.1.1/32",
                "10.0.0.1/32",
            ],
            allowed_ipv6_addresses=["2001:db8:85a3::8a2e:370:7334/128"],
            allowed_ports=[
                443,
                8443,
            ],
            disable_strict_networking=False)
        ```

        ## Import

        Vercel Secrets sync destinations can be imported using the `name`, e.g.

        ```sh
        $ pulumi import vault:secrets/syncVercelDestination:SyncVercelDestination vercel vercel-dest
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_token: Vercel API access token with the permissions to manage environment
               variables.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv4_addresses: Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
               for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv6_addresses: Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
               for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] allowed_ports: Set of allowed ports for outbound connections from Vault to the
               destination. If not set, all ports are allowed. Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] deployment_environments: Deployment environments where the environment variables
               are available. Accepts `development`, `preview` and `production`.
        :param pulumi.Input[_builtins.bool] disable_strict_networking: If set to `true`, disables strict networking enforcement
               for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
               Defaults to `false`. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] granularity: Determines what level of information is synced as a distinct resource
               at the destination. Supports `secret-path` and `secret-key`.
        :param pulumi.Input[_builtins.str] name: Unique name of the GitHub destination.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        :param pulumi.Input[_builtins.str] project_id: Project ID where to manage environment variables.
        :param pulumi.Input[_builtins.str] secret_name_template: Template describing how to generate external secret names.
               Supports a subset of the Go Template syntax.
        :param pulumi.Input[_builtins.str] team_id: Team ID where to manage environment variables.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SyncVercelDestinationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        vercel = vault.secrets.SyncVercelDestination("vercel",
            name="vercel-dest",
            access_token=access_token,
            project_id=project_id,
            deployment_environments=[
                "development",
                "preview",
                "production",
            ],
            secret_name_template="vault_{{ .MountAccessor | lowercase }}_{{ .SecretPath | lowercase }}",
            allowed_ipv4_addresses=[
                "192.168.1.1/32",
                "10.0.0.1/32",
            ],
            allowed_ipv6_addresses=["2001:db8:85a3::8a2e:370:7334/128"],
            allowed_ports=[
                443,
                8443,
            ],
            disable_strict_networking=False)
        ```

        ## Import

        Vercel Secrets sync destinations can be imported using the `name`, e.g.

        ```sh
        $ pulumi import vault:secrets/syncVercelDestination:SyncVercelDestination vercel vercel-dest
        ```

        :param str resource_name: The name of the resource.
        :param SyncVercelDestinationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SyncVercelDestinationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token: Optional[pulumi.Input[_builtins.str]] = None,
                 allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
                 deployment_environments: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
                 granularity: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SyncVercelDestinationArgs.__new__(SyncVercelDestinationArgs)

            if access_token is None and not opts.urn:
                raise TypeError("Missing required property 'access_token'")
            __props__.__dict__["access_token"] = None if access_token is None else pulumi.Output.secret(access_token)
            __props__.__dict__["allowed_ipv4_addresses"] = allowed_ipv4_addresses
            __props__.__dict__["allowed_ipv6_addresses"] = allowed_ipv6_addresses
            __props__.__dict__["allowed_ports"] = allowed_ports
            if deployment_environments is None and not opts.urn:
                raise TypeError("Missing required property 'deployment_environments'")
            __props__.__dict__["deployment_environments"] = deployment_environments
            __props__.__dict__["disable_strict_networking"] = disable_strict_networking
            __props__.__dict__["granularity"] = granularity
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["secret_name_template"] = secret_name_template
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["type"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["accessToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SyncVercelDestination, __self__).__init__(
            'vault:secrets/syncVercelDestination:SyncVercelDestination',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_token: Optional[pulumi.Input[_builtins.str]] = None,
            allowed_ipv4_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_ipv6_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            allowed_ports: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.int]]]] = None,
            deployment_environments: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            disable_strict_networking: Optional[pulumi.Input[_builtins.bool]] = None,
            granularity: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            namespace: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            secret_name_template: Optional[pulumi.Input[_builtins.str]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'SyncVercelDestination':
        """
        Get an existing SyncVercelDestination resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_token: Vercel API access token with the permissions to manage environment
               variables.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv4_addresses: Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
               for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] allowed_ipv6_addresses: Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
               for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
               Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.int]]] allowed_ports: Set of allowed ports for outbound connections from Vault to the
               destination. If not set, all ports are allowed. Requires Vault 1.19+.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] deployment_environments: Deployment environments where the environment variables
               are available. Accepts `development`, `preview` and `production`.
        :param pulumi.Input[_builtins.bool] disable_strict_networking: If set to `true`, disables strict networking enforcement
               for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
               Defaults to `false`. Requires Vault 1.19+.
        :param pulumi.Input[_builtins.str] granularity: Determines what level of information is synced as a distinct resource
               at the destination. Supports `secret-path` and `secret-key`.
        :param pulumi.Input[_builtins.str] name: Unique name of the GitHub destination.
        :param pulumi.Input[_builtins.str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        :param pulumi.Input[_builtins.str] project_id: Project ID where to manage environment variables.
        :param pulumi.Input[_builtins.str] secret_name_template: Template describing how to generate external secret names.
               Supports a subset of the Go Template syntax.
        :param pulumi.Input[_builtins.str] team_id: Team ID where to manage environment variables.
        :param pulumi.Input[_builtins.str] type: The type of the secrets destination (`vercel-project`).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SyncVercelDestinationState.__new__(_SyncVercelDestinationState)

        __props__.__dict__["access_token"] = access_token
        __props__.__dict__["allowed_ipv4_addresses"] = allowed_ipv4_addresses
        __props__.__dict__["allowed_ipv6_addresses"] = allowed_ipv6_addresses
        __props__.__dict__["allowed_ports"] = allowed_ports
        __props__.__dict__["deployment_environments"] = deployment_environments
        __props__.__dict__["disable_strict_networking"] = disable_strict_networking
        __props__.__dict__["granularity"] = granularity
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["secret_name_template"] = secret_name_template
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["type"] = type
        return SyncVercelDestination(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessToken")
    def access_token(self) -> pulumi.Output[_builtins.str]:
        """
        Vercel API access token with the permissions to manage environment
        variables.
        """
        return pulumi.get(self, "access_token")

    @_builtins.property
    @pulumi.getter(name="allowedIpv4Addresses")
    def allowed_ipv4_addresses(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Set of allowed IPv4 addresses in CIDR notation (e.g., `192.168.1.1/32`)
        for outbound connections from Vault to the destination. If not set, all IPv4 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv4_addresses")

    @_builtins.property
    @pulumi.getter(name="allowedIpv6Addresses")
    def allowed_ipv6_addresses(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Set of allowed IPv6 addresses in CIDR notation (e.g., `2001:db8::1/128`)
        for outbound connections from Vault to the destination. If not set, all IPv6 addresses are allowed.
        Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ipv6_addresses")

    @_builtins.property
    @pulumi.getter(name="allowedPorts")
    def allowed_ports(self) -> pulumi.Output[Optional[Sequence[_builtins.int]]]:
        """
        Set of allowed ports for outbound connections from Vault to the
        destination. If not set, all ports are allowed. Requires Vault 1.19+.
        """
        return pulumi.get(self, "allowed_ports")

    @_builtins.property
    @pulumi.getter(name="deploymentEnvironments")
    def deployment_environments(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Deployment environments where the environment variables
        are available. Accepts `development`, `preview` and `production`.
        """
        return pulumi.get(self, "deployment_environments")

    @_builtins.property
    @pulumi.getter(name="disableStrictNetworking")
    def disable_strict_networking(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If set to `true`, disables strict networking enforcement
        for this destination. When disabled, Vault will not enforce allowed IP addresses and ports.
        Defaults to `false`. Requires Vault 1.19+.
        """
        return pulumi.get(self, "disable_strict_networking")

    @_builtins.property
    @pulumi.getter
    def granularity(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Determines what level of information is synced as a distinct resource
        at the destination. Supports `secret-path` and `secret-key`.
        """
        return pulumi.get(self, "granularity")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Unique name of the GitHub destination.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault/index.html#namespace).
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Project ID where to manage environment variables.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="secretNameTemplate")
    def secret_name_template(self) -> pulumi.Output[_builtins.str]:
        """
        Template describing how to generate external secret names.
        Supports a subset of the Go Template syntax.
        """
        return pulumi.get(self, "secret_name_template")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Team ID where to manage environment variables.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the secrets destination (`vercel-project`).
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSecretBackendSignResult',
    'AwaitableGetSecretBackendSignResult',
    'get_secret_backend_sign',
    'get_secret_backend_sign_output',
]

@pulumi.output_type
class GetSecretBackendSignResult:
    """
    A collection of values returned by getSecretBackendSign.
    """
    def __init__(__self__, cert_type=None, critical_options=None, extensions=None, id=None, key_id=None, name=None, namespace=None, path=None, public_key=None, serial_number=None, signed_key=None, ttl=None, valid_principals=None):
        if cert_type and not isinstance(cert_type, str):
            raise TypeError("Expected argument 'cert_type' to be a str")
        pulumi.set(__self__, "cert_type", cert_type)
        if critical_options and not isinstance(critical_options, dict):
            raise TypeError("Expected argument 'critical_options' to be a dict")
        pulumi.set(__self__, "critical_options", critical_options)
        if extensions and not isinstance(extensions, dict):
            raise TypeError("Expected argument 'extensions' to be a dict")
        pulumi.set(__self__, "extensions", extensions)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_id and not isinstance(key_id, str):
            raise TypeError("Expected argument 'key_id' to be a str")
        pulumi.set(__self__, "key_id", key_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if public_key and not isinstance(public_key, str):
            raise TypeError("Expected argument 'public_key' to be a str")
        pulumi.set(__self__, "public_key", public_key)
        if serial_number and not isinstance(serial_number, str):
            raise TypeError("Expected argument 'serial_number' to be a str")
        pulumi.set(__self__, "serial_number", serial_number)
        if signed_key and not isinstance(signed_key, str):
            raise TypeError("Expected argument 'signed_key' to be a str")
        pulumi.set(__self__, "signed_key", signed_key)
        if ttl and not isinstance(ttl, str):
            raise TypeError("Expected argument 'ttl' to be a str")
        pulumi.set(__self__, "ttl", ttl)
        if valid_principals and not isinstance(valid_principals, str):
            raise TypeError("Expected argument 'valid_principals' to be a str")
        pulumi.set(__self__, "valid_principals", valid_principals)

    @_builtins.property
    @pulumi.getter(name="certType")
    def cert_type(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "cert_type")

    @_builtins.property
    @pulumi.getter(name="criticalOptions")
    def critical_options(self) -> Optional[Mapping[str, _builtins.str]]:
        return pulumi.get(self, "critical_options")

    @_builtins.property
    @pulumi.getter
    def extensions(self) -> Optional[Mapping[str, _builtins.str]]:
        return pulumi.get(self, "extensions")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="keyId")
    def key_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "key_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter
    def path(self) -> _builtins.str:
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> _builtins.str:
        return pulumi.get(self, "public_key")

    @_builtins.property
    @pulumi.getter(name="serialNumber")
    def serial_number(self) -> _builtins.str:
        """
        The serial number of the certificate returned from Vault
        """
        return pulumi.get(self, "serial_number")

    @_builtins.property
    @pulumi.getter(name="signedKey")
    def signed_key(self) -> _builtins.str:
        """
        The signed certificate returned from Vault
        """
        return pulumi.get(self, "signed_key")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "ttl")

    @_builtins.property
    @pulumi.getter(name="validPrincipals")
    def valid_principals(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "valid_principals")


class AwaitableGetSecretBackendSignResult(GetSecretBackendSignResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecretBackendSignResult(
            cert_type=self.cert_type,
            critical_options=self.critical_options,
            extensions=self.extensions,
            id=self.id,
            key_id=self.key_id,
            name=self.name,
            namespace=self.namespace,
            path=self.path,
            public_key=self.public_key,
            serial_number=self.serial_number,
            signed_key=self.signed_key,
            ttl=self.ttl,
            valid_principals=self.valid_principals)


def get_secret_backend_sign(cert_type: Optional[_builtins.str] = None,
                            critical_options: Optional[Mapping[str, _builtins.str]] = None,
                            extensions: Optional[Mapping[str, _builtins.str]] = None,
                            key_id: Optional[_builtins.str] = None,
                            name: Optional[_builtins.str] = None,
                            namespace: Optional[_builtins.str] = None,
                            path: Optional[_builtins.str] = None,
                            public_key: Optional[_builtins.str] = None,
                            ttl: Optional[_builtins.str] = None,
                            valid_principals: Optional[_builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecretBackendSignResult:
    """
    This is a data source which can be used to sign an SSH public key

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    test = vault.ssh.get_secret_backend_sign(path="ssh",
        public_key="ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABgQDR6q4PTcuIkpdGEqaCaxnR8/REqlbSiEIKaRZkVSjiTXOaiSfUsy9cY2+7+oO9fLMUrhylImerjzEoagX1IjYvc9IeUBaRnfacN7QwUDfstgp2jknbg7rNX9j9nFxwltV/jYQPcRq8Ud0wn1nb4qixq+diM7+Up+xJOeaKxbpjEUJH5dcvaBB+Aa24tJpjOQxtFyQ6dUxlgJu0tcygZR92kKYCVjZDohlSED3i/Ak2KFwqCKx2IZWq9z1vMEgmRzv++4Qt1OsbpW8itiCyWn6lmV33eDCdjMrr9TEThQNnMinPrHdmVUnPZ/OomP+rLDRE9lQR16uaSvKhg5TWOFIXRPyEhX9arEATrE4KSWeQN2qgHOb6P24YqgEm1ZdHJq25q/nBBAa1x0tFMiWqZwOsGeJ9nTeOeyiqFKH5YRBo6DIy3ag3taFsfQSve6oqjnrudUd1hJ8/bNSz8amECfP0ULvAEAgpiurj3eCPc3OcXl4tAld9F6KwabEJV5eelcs= user@example.com",
        name="test",
        valid_principals="my-user")
    ```


    :param _builtins.str cert_type: Specifies the type of certificate to be created; either "user" or "host".
    :param Mapping[str, _builtins.str] critical_options: Specifies a map of the critical options that the certificate should be signed for. Defaults to none.
    :param Mapping[str, _builtins.str] extensions: Specifies a map of the extensions that the certificate should be signed for. Defaults to none.
    :param _builtins.str key_id: Specifies the key id that the created certificate should have. If not specified, the display name of the token will be used.
    :param _builtins.str name: Specifies the name of the role to sign.
    :param _builtins.str path: Full path where SSH backend is mounted.
    :param _builtins.str public_key: Specifies the SSH public key that should be signed.
    :param _builtins.str ttl: Specifies the Requested Time To Live. Cannot be greater than the role's max_ttl value. If not provided, the role's ttl value will be used. Note that the role values default to system values if not explicitly set.
    :param _builtins.str valid_principals: Specifies valid principals, either usernames or hostnames, that the certificate should be signed for. Required unless the role has specified allow_empty_principals or a value has been set for either the default_user or default_user_template role parameters.
    """
    __args__ = dict()
    __args__['certType'] = cert_type
    __args__['criticalOptions'] = critical_options
    __args__['extensions'] = extensions
    __args__['keyId'] = key_id
    __args__['name'] = name
    __args__['namespace'] = namespace
    __args__['path'] = path
    __args__['publicKey'] = public_key
    __args__['ttl'] = ttl
    __args__['validPrincipals'] = valid_principals
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vault:ssh/getSecretBackendSign:getSecretBackendSign', __args__, opts=opts, typ=GetSecretBackendSignResult).value

    return AwaitableGetSecretBackendSignResult(
        cert_type=pulumi.get(__ret__, 'cert_type'),
        critical_options=pulumi.get(__ret__, 'critical_options'),
        extensions=pulumi.get(__ret__, 'extensions'),
        id=pulumi.get(__ret__, 'id'),
        key_id=pulumi.get(__ret__, 'key_id'),
        name=pulumi.get(__ret__, 'name'),
        namespace=pulumi.get(__ret__, 'namespace'),
        path=pulumi.get(__ret__, 'path'),
        public_key=pulumi.get(__ret__, 'public_key'),
        serial_number=pulumi.get(__ret__, 'serial_number'),
        signed_key=pulumi.get(__ret__, 'signed_key'),
        ttl=pulumi.get(__ret__, 'ttl'),
        valid_principals=pulumi.get(__ret__, 'valid_principals'))
def get_secret_backend_sign_output(cert_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   critical_options: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                                   extensions: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                                   key_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   name: Optional[pulumi.Input[_builtins.str]] = None,
                                   namespace: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   path: Optional[pulumi.Input[_builtins.str]] = None,
                                   public_key: Optional[pulumi.Input[_builtins.str]] = None,
                                   ttl: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   valid_principals: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecretBackendSignResult]:
    """
    This is a data source which can be used to sign an SSH public key

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vault as vault

    test = vault.ssh.get_secret_backend_sign(path="ssh",
        public_key="ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABgQDR6q4PTcuIkpdGEqaCaxnR8/REqlbSiEIKaRZkVSjiTXOaiSfUsy9cY2+7+oO9fLMUrhylImerjzEoagX1IjYvc9IeUBaRnfacN7QwUDfstgp2jknbg7rNX9j9nFxwltV/jYQPcRq8Ud0wn1nb4qixq+diM7+Up+xJOeaKxbpjEUJH5dcvaBB+Aa24tJpjOQxtFyQ6dUxlgJu0tcygZR92kKYCVjZDohlSED3i/Ak2KFwqCKx2IZWq9z1vMEgmRzv++4Qt1OsbpW8itiCyWn6lmV33eDCdjMrr9TEThQNnMinPrHdmVUnPZ/OomP+rLDRE9lQR16uaSvKhg5TWOFIXRPyEhX9arEATrE4KSWeQN2qgHOb6P24YqgEm1ZdHJq25q/nBBAa1x0tFMiWqZwOsGeJ9nTeOeyiqFKH5YRBo6DIy3ag3taFsfQSve6oqjnrudUd1hJ8/bNSz8amECfP0ULvAEAgpiurj3eCPc3OcXl4tAld9F6KwabEJV5eelcs= user@example.com",
        name="test",
        valid_principals="my-user")
    ```


    :param _builtins.str cert_type: Specifies the type of certificate to be created; either "user" or "host".
    :param Mapping[str, _builtins.str] critical_options: Specifies a map of the critical options that the certificate should be signed for. Defaults to none.
    :param Mapping[str, _builtins.str] extensions: Specifies a map of the extensions that the certificate should be signed for. Defaults to none.
    :param _builtins.str key_id: Specifies the key id that the created certificate should have. If not specified, the display name of the token will be used.
    :param _builtins.str name: Specifies the name of the role to sign.
    :param _builtins.str path: Full path where SSH backend is mounted.
    :param _builtins.str public_key: Specifies the SSH public key that should be signed.
    :param _builtins.str ttl: Specifies the Requested Time To Live. Cannot be greater than the role's max_ttl value. If not provided, the role's ttl value will be used. Note that the role values default to system values if not explicitly set.
    :param _builtins.str valid_principals: Specifies valid principals, either usernames or hostnames, that the certificate should be signed for. Required unless the role has specified allow_empty_principals or a value has been set for either the default_user or default_user_template role parameters.
    """
    __args__ = dict()
    __args__['certType'] = cert_type
    __args__['criticalOptions'] = critical_options
    __args__['extensions'] = extensions
    __args__['keyId'] = key_id
    __args__['name'] = name
    __args__['namespace'] = namespace
    __args__['path'] = path
    __args__['publicKey'] = public_key
    __args__['ttl'] = ttl
    __args__['validPrincipals'] = valid_principals
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vault:ssh/getSecretBackendSign:getSecretBackendSign', __args__, opts=opts, typ=GetSecretBackendSignResult)
    return __ret__.apply(lambda __response__: GetSecretBackendSignResult(
        cert_type=pulumi.get(__response__, 'cert_type'),
        critical_options=pulumi.get(__response__, 'critical_options'),
        extensions=pulumi.get(__response__, 'extensions'),
        id=pulumi.get(__response__, 'id'),
        key_id=pulumi.get(__response__, 'key_id'),
        name=pulumi.get(__response__, 'name'),
        namespace=pulumi.get(__response__, 'namespace'),
        path=pulumi.get(__response__, 'path'),
        public_key=pulumi.get(__response__, 'public_key'),
        serial_number=pulumi.get(__response__, 'serial_number'),
        signed_key=pulumi.get(__response__, 'signed_key'),
        ttl=pulumi.get(__response__, 'ttl'),
        valid_principals=pulumi.get(__response__, 'valid_principals')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .auth_backend_login import *
from .auth_backend_role import *
from .auth_backend_role_secret_id import *
from .get_auth_backend_role_id import *
